@@ -1,4 +1,5 @@
 from .auth import Session, get_session, initialize, reset
 from .error import GeoEngineException, InputException, UninitializedException, TypeException
-from .types import Bbox
+from .types import QueryRectangle
 from .workflow import WorkflowId, Workflow, workflow_by_id, register_workflow
+from .datasets import upload_dataframe
